#
# spec file for package perl-Future-IO
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Future-IO
Name:           perl-Future-IO
Version:        0.14
Release:        bp156.1.2
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Future-returning IO methods
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PE/PEVANS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Future)
BuildRequires:  perl(Module::Build) >= 0.400400
BuildRequires:  perl(Struct::Dumb)
BuildRequires:  perl(Test2::V0)
BuildRequires:  perl(Test::Future::IO::Impl)
Requires:       perl(Future)
Requires:       perl(Struct::Dumb)
%{perl_requires}

%description
This package provides a few basic methods that behave similarly to the
same-named core perl functions relating to IO operations, but yield their
results asynchronously via Future instances.

This is provided primarily as a decoupling mechanism, to allow modules to
be written that perform IO in an asynchronous manner to depend directly on
this, while allowing asynchronous event systems to provide an
implementation of these operations.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Wed Apr 26 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.14
  see /usr/share/doc/packages/perl-Future-IO/Changes
  0.14    2023-04-25
    [CHANGES]
  * Moved `Test::Future::IO::Impl` into its own distribution, so that
    downstream packages don't have to runtime-depend on `Test2`
* Mon Feb 20 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.13
  see /usr/share/doc/packages/perl-Future-IO/Changes
  0.13    2023-02-19
    [CHANGES]
  * Swap all unit tests from `Test::More` to `Test2::V0`
  * Reomved test-time dependency on `Test::Identity`
    [BUGFIXES]
  * t/30system.t should check that the impl actually provides a
    `->waitpid` method before using it
  * Insert a hacky "sleep 1" into the connect tests on MSWin32 in case
    that helps fix the test failures
* Wed Feb  1 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.12
  see /usr/share/doc/packages/perl-Future-IO/Changes
  0.12    2023-01-31
    [CHANGES]
  * Added `Future::IO::System`, containing a system()-like and a
    qx()-like method
  * Added `->sysread_until_eof` method
  * Update to perl v5.14 `package NAME VERSION` syntax
  * Use `await` notation in method minisynopsis lines
    [BUGFIXES]
  * Need to work harder to set LocalAddr during socket tests
* Tue Aug 16 2022 Tina Müller <tina.mueller@suse.com>
- Initial submission
